@@ -69,7 +69,7 @@ class AnalysisForm(forms.Form):
                             ('D','Dialog'),)
     #FETCH_CHOICES = (('PrevSemPred','PrevSemPred'),
     #                'FollSemPred','FollSemPred')
-    SENSE_OPTIONS = (('Disambiguate','Disambiguate')
+    SENSE_OPTIONS = (('Disambiguate','Disambiguate'),
                     ('Default','Default'))
     measure = forms.CharField(label='Measure')
     measure.widget = forms.Select(choices=M_CHOICES)
