@@ -134,6 +134,7 @@ class Speaker(caching.base.CachingMixin,models.Model):
     def analyze(self,form):
         words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker')
         words = words.filter(WordType__Label__regex = '^[^{<]').filter(Dialog__Speaker=self)
+        words = words.exclude(WordType__CVSkel__regex = '^C*VC*$')
         #words = words.filter(WordType__CVSkel='CVC')
         #words = words.filter(WordType__Label__in = GOOD_WORDS)
         #words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
@@ -142,8 +143,8 @@ class Speaker(caching.base.CachingMixin,models.Model):
         print("\n")
         print(len(words))
         for w in words:
-            if settings.DEBUG:
-                print(w.pk)
+            #if settings.DEBUG:
+            #    print(w.pk)
             if not w.WordType.isAcceptable():
                 continue
             if not w.isAcceptable():
@@ -154,8 +155,8 @@ class Speaker(caching.base.CachingMixin,models.Model):
             if out is None:
                 continue
             allout.extend(out)
-            if settings.DEBUG:
-                print allout[-1]
+            #if settings.DEBUG:
+            #    print allout[-1]
         return allout
 
     def load_dialogs(self):
